@@ -25,11 +25,11 @@
 BrowserLauncher::BrowserLauncher(QObject *parent) :
     QObject(parent)
 {
-    prefer_touch = settings_manager.is_prefer_facebook_touch();
 }
 
 void BrowserLauncher::launch_facebook()
 {
+    prefer_touch = settings_manager.is_prefer_facebook_touch();
     if (prefer_touch) launch_facebook_touch();
     else launch_facebook_full();
 }
@@ -44,20 +44,3 @@ void BrowserLauncher::launch_facebook_touch()
     desktop_services.openUrl(FACEBOOK_TOUCH_URL);
 }
 
-void BrowserLauncher::set_touch_preferred(bool prefer_touch)
-{
-    //Only emit if there is an actual change.
-    qDebug()<<"prefer touch = "<<prefer_touch;
-    if (this->prefer_touch != prefer_touch)
-    {
-        this->prefer_touch = prefer_touch;
-        settings_manager.set_prefer_facebook_touch(prefer_touch);
-        emit touch_preferred_changed(prefer_touch);
-    }
-}
-
-void BrowserLauncher::request_settings()
-{
-    emit touch_preferred_changed(prefer_touch);
-}
-
