@@ -11,7 +11,7 @@ class Message : public QObject
     Q_OBJECT
 public:
     explicit Message(QObject *parent = 0);
-    enum MessageType {STATUS,CHECKIN};
+    enum MessageType {STATUS,CHECKIN,LINK,POST};
 
     int getId() {return this->_id;}
     void setId(int id) {this->_id = id;}
@@ -26,6 +26,9 @@ public:
     void addComment(Comment *comment) {this->_comments.append(comment);}
     QList<Comment *> getComments() {return this->_comments;}
 
+    int getLikeCount() {return this->_likeCount;}
+    void setLikeCount(int likeCount) {this->_likeCount = likeCount;}
+
 signals:
 
 public slots:
@@ -38,6 +41,7 @@ private:
     QString _text;
     QDateTime _timestamp;
     QList<Comment *> _comments;
+    int _likeCount;
 
 };
 
