@@ -23,9 +23,6 @@
 #include "constants.h"
 #include "facebookgraph/facebookgraph.h"
 #include "configdialog.h"
-#include <QByteArray>
-#include <QtNetwork/QNetworkAccessManager>
-#include <QtNetwork/QNetworkRequest>
 #include <QUrl>
 #include <QList>
 #include <QMessageBox>
@@ -51,13 +48,14 @@ void FbActions::request_status()
         QUrl url;
         url.setScheme("https");
         url.setHost(AUTH_HOST);
-        url.setPath("/me/statuses");
+        url.setPath("/me/posts");
         url.addQueryItem("access_token",token);
-        url.addQueryItem("limit","10");
-        url.addQueryItem("fields","id,message,updated_time,comments");
+//        url.addQueryItem("limit","10");
+//        url.addQueryItem("fields","id,message,updated_time,comments");
         qDebug()<<"about to request url: "<<url.toString();
         QNetworkRequest req(url);
-        access_manager.get(req);
+        QNetworkReply* reply = access_manager.get(req);
+        status_replies.append(reply);
     }
 }
 
@@ -82,19 +80,19 @@ void FbActions::handle_http_response(QNetworkReply *reply)
     if (reply->error()==QNetworkReply::NoError) {
         QByteArray bytes = reply->readAll();
         qDebug()<<"http response: "<<bytes;
-        FacebookGraph facebookGraph(0,bytes);
-        switch (facebookGraph.getParseResult())
+        if (status_replies.contains(reply))
+        {
+            handle_status_response(bytes);
+            status_replies.removeAll(reply);
+        }
+        else if (set_status_replies.contains(reply))
+        {
+            handle_set_status_response(bytes);
+            set_status_replies.removeAll(reply);
+        }
+        else
         {
-        case FacebookGraph::ERROR:
             emit_simple_message(tr("Unknown response from Facebook."));
-            break;
-        case FacebookGraph::MESSAGES:
-            emit status_available(QVariant(facebookGraph.getFormattedMessage()));
-            break;
-        case FacebookGraph::STATUS_SUCCESSFUL:
-            emit status_successfully_set();
-            request_status();
-            break;
         }
     } else {
         emit_simple_message(QString(tr("Network error: %1")).arg(reply->errorString()));
@@ -102,6 +100,27 @@ void FbActions::handle_http_response(QNetworkReply *reply)
     reply->deleteLater();
 }
 
+void FbActions::handle_status_response(QByteArray bytes)
+{
+    FacebookGraph facebookGraph(0,bytes);
+    if (facebookGraph.getParseResult() == FacebookGraph::MESSAGES)
+        emit status_available(QVariant(facebookGraph.getFormattedMessage()));
+    else
+        emit_simple_message(tr("Unknown response from Facebook."));
+}
+
+void FbActions::handle_set_status_response(QByteArray bytes)
+{
+    FacebookGraph facebookGraph(0,bytes);
+    if (facebookGraph.getParseResult() == FacebookGraph::STATUS_SUCCESSFUL)
+    {
+        emit status_successfully_set();
+        request_status();
+    }
+    else
+        emit_simple_message(tr("Unknown response from Facebook."));
+}
+
 void FbActions::unauthorize()
 {
     settings_manager.clear_facebook_auth();
@@ -126,7 +145,8 @@ void FbActions::set_status(QString status)
     QString encodedStatus(QUrl::toPercentEncoding(status,"",""));
     QString post_data = QString("access_token=%1&message=%2").arg(token,encodedStatus);
     qDebug()<<"using post data: "<<post_data;
-    access_manager.post(req,post_data.toAscii());
+    QNetworkReply* reply = access_manager.post(req,post_data.toAscii());
+    set_status_replies.append(reply);
 }
 
 void FbActions::emit_simple_message(QString text)
